@@ -6,7 +6,7 @@ import logging
 from logging.handlers import RotatingFileHandler
 from msi_auth import MSIAuth
 from aad_auth import AADAuth
-
+import json
 
 # Specify files accessed by this script in guestshell
 base_dir = expanduser('~') + '/cloud/authMgr/'
@@ -158,33 +158,26 @@ def clear_token(logger, app=None):
     return 'ERR: No authentication application found for clearing a token'
 
 def write_table_to_file():
+    app_desc = {}
     with open(aad_app_file, 'w') as write_fh:
-        app_desc = "{cloud: %s, app_id: %s, tenant_id: %s, app_key: %s}" % (default_aad_app.cloud, default_aad_app.app_id, default_aad_app.tenant_id, default_aad_app.app_key)
-        out_str = str(app_desc) + '\n'
+        app_desc['cloud'] = default_aad_app.cloud
+        app_desc['app_id'] = default_aad_app.app_id
+        app_desc['tenant_id'] = default_aad_app.tenant_id
+        app_desc['app_key'] = default_aad_app.app_key
+        out_str = json.dumps(app_desc)
         print("Writing app_desc to file")
         print("%s" % out_str)
         write_fh.write(out_str)
 
 def read_table_from_file(logger):
     if os.path.exists(aad_app_file):
+        out_var = {}
         with open(aad_app_file, 'r') as read_fh:
-            for line in read_fh:
-                input_str = line.strip()
-                print("Read table from file")
-                print("%s" % input_str)
-                substr1 = input_str.replace('{', '')
-                substr2 = substr1.replace('}', '')
-                # Separate items into list of strings
-                list_of_pairs = substr2.rsplit(',')
-                # Create an empty dict
-                out_var={}
-                for list_entry in list_of_pairs:
-                    # Split the entry into a key and value
-                    key_value_pair = list_entry.rsplit(':')
-                    key = key_value_pair[0].strip()
-                    value = key_value_pair[1].strip()
-                    out_var[key] = value
-                set_default_aad_app(logger, out_var['cloud'], out_var['app_id'], out_var['tenant_id'], out_var['app_key'])
+            input_str = read_fh.read().strip()
+            out_var = json.loads(input_str)
+            print("Read table from file")
+            print("%s" % input_str)
+            set_default_aad_app(logger, out_var['cloud'], out_var['tenant_id'], out_var['app_id'], out_var['app_key'])
 
 
 def show():
