@@ -2,7 +2,7 @@
 
 from __future__ import print_function
 import sys
-from token_api import Token_api as token_api
+from csr_cloud.token_api import Token_api as token_api
 import argparse
 
 
